California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 028 - LIMITS ON LEGISLATORS' TERMS IN OFFICE. INITIATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1322596 | CALIFORNIANS FOR A FRESH START, SPONSORED BY BUSINESS AND LABOR ORGANIZATIONS, A COALITION OF BUSINESSES, BUSINESSPERSONS, AND WORKING MEN AND WOMEN TO SUPPORT PROP. 28 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1302429 | LOS ANGELES COUNTY FEDERATION OF LABOR, AFL-CIO ISSUES AND INITIATIVES COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1303307 | ALLIANCE FOR A STRONGER COMMUNITY TO SUPPORT PROP. 28 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1345381 | CALIFORNIANS FOR TERM LIMITS, NO ON PROP 28, WITH MAJOR FUNDING FROM THE LIBERTY INITIATIVE FUND | OPPOSE